package com.kgraph.graph.mapper;

import java.util.List;
import com.kgraph.graph.domain.ProcessedFile;

/**
 * 处理文件管理Mapper接口
 * 
 * @author Allen
 * @date 2023-10-16
 */
public interface ProcessedFileMapper 
{
    /**
     * 查询处理文件管理
     * 
     * @param id 处理文件管理主键
     * @return 处理文件管理
     */
    public ProcessedFile selectProcessedFileById(Long id);

    /**
     * 查询处理文件管理列表
     * 
     * @param processedFile 处理文件管理
     * @return 处理文件管理集合
     */
    public List<ProcessedFile> selectProcessedFileList(ProcessedFile processedFile);

    /**
     * 新增处理文件管理
     * 
     * @param processedFile 处理文件管理
     * @return 结果
     */
    public int insertProcessedFile(ProcessedFile processedFile);

    /**
     * 修改处理文件管理
     * 
     * @param processedFile 处理文件管理
     * @return 结果
     */
    public int updateProcessedFile(ProcessedFile processedFile);

    /**
     * 删除处理文件管理
     * 
     * @param id 处理文件管理主键
     * @return 结果
     */
    public int deleteProcessedFileById(Long id);

    /**
     * 批量删除处理文件管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProcessedFileByIds(Long[] ids);

    List getOptionsBySourceFileId(Long id);
}
